==> wikitty-api-3.6-sources.jar: org/nuiton/wikitty/entities/WikittyUserHelper.java <==
package org.nuiton.wikitty.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;

public class WikittyUserHelper {

    /**
     * utility class all provided methods are accessible the static way
     */
    private WikittyUserHelper() {// empty
}

    public static String getLogin(Wikitty wikitty) {
        String value = wikitty.getFieldAsString(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_LOGIN);
        return value;
}

    public static String setLogin(Wikitty wikitty, String login) {
        String oldValue = getLogin(wikitty);
        wikitty.setField(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_LOGIN, login);
        return oldValue;
}

    public static String getPassword(Wikitty wikitty) {
        String value = wikitty.getFieldAsString(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_PASSWORD);
        return value;
}

    public static String setPassword(Wikitty wikitty, String password) {
        String oldValue = getPassword(wikitty);
        wikitty.setField(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_PASSWORD, password);
        return oldValue;
}

    public static boolean equals(Wikitty w1, Wikitty w2) {
    boolean result = true;

        if (result) {
            Object f1 = w1.getFieldAsObject(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_LOGIN);
            Object f2 = w2.getFieldAsObject(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_LOGIN);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

        if (result) {
            Object f1 = w1.getFieldAsObject(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_PASSWORD);
            Object f2 = w2.getFieldAsObject(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_PASSWORD);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

    return result;
}

    /**
     * @deprecated renamed to keep consistency, use hasExtension instead
     * @param wikitty 
     * @return 
     */
    @Deprecated
    public static boolean isExtension(Wikitty wikitty) {
        return hasExtension(wikitty);
}

    /**
     * check if wikitty has current extension
     * @param wikitty 
     * @return 
     */
    public static boolean hasExtension(Wikitty wikitty) {
        return wikitty.hasExtension(WikittyUser.EXT_WIKITTYUSER);
}

    /**
     * ajout les extensions static de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void addExtension(Wikitty wikitty) {
        for (WikittyExtension ext : WikittyUserAbstract.extensions) {
            wikitty.addExtension(ext);
        }
}

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @param wikitty 
     * @return 
     */
    public static String toString(Wikitty wikitty) {

        return wikitty.toString(WikittyUser.EXT_WIKITTYUSER);
}

} //WikittyUserHelper

==> wikitty-api-3.10-sources.jar: org/nuiton/wikitty/entities/WikittyUserHelper.java <==
package org.nuiton.wikitty.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;

public class WikittyUserHelper {

    /**
     * utility class all provided methods are accessible the static way
     */
    private WikittyUserHelper() {// empty
}

    public static String getLogin(Wikitty wikitty) {
        String value = wikitty.getFieldAsString(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_LOGIN);
        return value;
}

    public static String setLogin(Wikitty wikitty, String login) {
        String oldValue = getLogin(wikitty);
        wikitty.setField(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_LOGIN, login);
        return oldValue;
}

    public static String getPassword(Wikitty wikitty) {
        String value = wikitty.getFieldAsString(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_PASSWORD);
        return value;
}

    public static String setPassword(Wikitty wikitty, String password) {
        String oldValue = getPassword(wikitty);
        wikitty.setField(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_PASSWORD, password);
        return oldValue;
}

    public static boolean equals(Wikitty w1, Wikitty w2) {
    boolean result = true;

        if (result) {
            Object f1 = w1.getFieldAsObject(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_LOGIN);
            Object f2 = w2.getFieldAsObject(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_LOGIN);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

        if (result) {
            Object f1 = w1.getFieldAsObject(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_PASSWORD);
            Object f2 = w2.getFieldAsObject(WikittyUser.EXT_WIKITTYUSER, WikittyUser.FIELD_WIKITTYUSER_PASSWORD);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

    return result;
}

    /**
     * @deprecated renamed to keep consistency, use hasExtension instead
     * @param wikitty 
     * @return 
     */
    @Deprecated
    public static boolean isExtension(Wikitty wikitty) {
        return hasExtension(wikitty);
}

    /**
     * check if wikitty has current extension
     * @param wikitty 
     * @return 
     */
    public static boolean hasExtension(Wikitty wikitty) {
        return wikitty.hasExtension(WikittyUser.EXT_WIKITTYUSER);
}

    /**
     * ajout les extensions static de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void addExtension(Wikitty wikitty) {
        for (WikittyExtension ext : WikittyUserAbstract.extensions) {
            wikitty.addExtension(ext);
        }
}

    /**
     * supprime les extensions de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void removeExtension(Wikitty wikitty) {
        for (WikittyExtension ext : WikittyUserAbstract.extensions) {
            wikitty.removeExtension(ext.getName());
        }
}

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @param wikitty 
     * @return 
     */
    public static String toString(Wikitty wikitty) {

        return wikitty.toString(WikittyUser.EXT_WIKITTYUSER);
}

} //WikittyUserHelper
